import 'package:equatable/equatable.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:square_connect/square_connect.dart';

part 'retrieve_gift_card_from_nonce.g.dart';

@JsonSerializable()
class RetrieveGiftCardFromNonceRequest extends Equatable {
  const RetrieveGiftCardFromNonceRequest({
    required this.nonce,
  });

  /// Converts a [Map] to an [RetrieveGiftCardFromNonceRequest]
  factory RetrieveGiftCardFromNonceRequest.fromJson(
    Map<String, dynamic> json,
  ) =>
      _$RetrieveGiftCardFromNonceRequestFromJson(json);

  /// Converts a [RetrieveGiftCardFromNonceRequest] to a [Map]
  Map<String, dynamic> toJson() =>
      _$RetrieveGiftCardFromNonceRequestToJson(this);

  /// The payment token of the gift card to retrieve. Payment tokens are
  /// generated by the Web Payments SDK or In-App Payments SDK.
  final String nonce;

  @override
  List<Object?> get props => [nonce];
}

@JsonSerializable()
class RetrieveGiftCardFromNonceResponse extends SquareResponse {
  const RetrieveGiftCardFromNonceResponse({this.giftCard, super.errors});

  /// Converts a [Map] to an [RetrieveGiftCardFromNonceResponse]
  factory RetrieveGiftCardFromNonceResponse.fromJson(
    Map<String, dynamic> json,
  ) =>
      _$RetrieveGiftCardFromNonceResponseFromJson(json);

  /// Converts a [RetrieveGiftCardFromNonceResponse] to a [Map]
  Map<String, dynamic> toJson() =>
      _$RetrieveGiftCardFromNonceResponseToJson(this);

  /// The retrieved gift card.
  final GiftCard? giftCard;

  @override
  List<Object?> get props => [errors, giftCard];
}
